#!/bin/bash
#
# ============LICENSE_START=======================================================
#  Copyright (C) 2018-2019 Nordix Foundation.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================
set -o errexit
set -o nounset

gitlog(){
    git log --pretty=format:'%Cred%h|%Cgreen%an|%Cblue%s%Creset' | \
    awk -F '|' '{ printf "%s %-20s %s\n", $1, $2, $3 }' | head -${1}
}

# There could be 2 directory with source: geode or geode-native
cd ${WORKSPACE}/geode*
GEODE_VERSION=$(git describe --abbrev=0 --tags | sed -r "s#rel/v(.*)#\1#")
GIT_LOGS=8

# Make sure the Geode tag version is in agreed format: \d.\d.\d.\d.[RC\d]?
if [[ ${GEODE_VERSION} =~ ^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+(\.RC[0-9]+)?$ ]] ; then
   echo -e "\n--------------------------------------------------------------------------"
   echo -e "\nTesting Geode version: ${GEODE_VERSION}\n"
   echo -e "------------------- Summary for last commit on the branch ------------------"
   git show --stat
   echo -e "\n--------------- The last ${GIT_LOGS} commits on the branch ---------------"
   gitlog ${GIT_LOGS}
else
   echo "ERROR: Incorrect geode tag version on the branch: ${GEODE_VERSION}"
   exit 1
fi
